-- MySQL 5.0 Consolidated database with SQL Anywhere 11 remote using TCPIP Synchronization
-- SQL Anywhere Studio MobiLink Synchronization 11
-- Written by Joshua Savill
-- Product Manager - Sybase iAnywhere
-- September 9, 2008

--
-- Create the tables to be involved in synchronization
--

create table Admin (
  admin_id      bigint not null auto_increment primary key,
  data          varchar(30),
  last_modified datetime not null default 1900/01/01 00:00:00
);

create table Track_Deletes_Admin (
  pkey         bigint not null auto_increment primary key,
  id           bigint not null,
  time_deleted datetime not null
);

create table Parent (
  parent_id     bigint not null auto_increment primary key,
  user_id       varchar(128),
  data          varchar(30),
  last_modified datetime not null default 1900/01/01 00:00:00
);

create table Track_Deletes_Parent (
  pkey         bigint not null auto_increment primary key,
  id           bigint not null,
  time_deleted datetime not null
);

create table Child (
  child_id      bigint not null auto_increment primary key,
  parent_id     bigint references Parent,
  data          varchar( 30 ),
  last_modified datetime not null default 1900/01/01 00:00:00
);

create table Track_Deletes_Child (
  pkey         bigint not null auto_increment primary key,
  id           bigint not null,
  time_deleted datetime not null
);

create table Inventory (
  inventory_id      bigint not null auto_increment primary key,
  data          int not null,
  last_modified datetime not null default 1900/01/01 00:00:00
);

create table Track_Deletes_Inventory (
  pkey         bigint not null auto_increment primary key,
  id           bigint not null,
  time_deleted datetime not null
);

--
-- Create the necessary triggers for synchronization and data
-- management
--

DELIMITER |

CREATE TRIGGER bi_admin BEFORE INSERT ON Admin FOR EACH ROW
BEGIN
  SET NEW.last_modified = now();
END;
|

CREATE TRIGGER bu_admin BEFORE UPDATE ON Admin FOR EACH ROW
BEGIN
  SET NEW.last_modified = now();
END;
|

CREATE TRIGGER bd_admin BEFORE DELETE ON Admin FOR EACH ROW
BEGIN
  INSERT INTO Track_Deletes_Admin (id, time_deleted) VALUES (OLD.admin_id, now() );
END;
|

CREATE TRIGGER bi_parent BEFORE INSERT ON Parent FOR EACH ROW
BEGIN
  SET NEW.last_modified = now();
END;
|

CREATE TRIGGER bu_parent BEFORE UPDATE ON Parent FOR EACH ROW
BEGIN
  SET NEW.last_modified = now();
END;
|

CREATE TRIGGER bd_parent BEFORE DELETE ON Parent FOR EACH ROW
BEGIN
  INSERT INTO Track_Deletes_Parent (id, time_deleted) VALUES (OLD.parent_id, now() );
END;
|

CREATE TRIGGER bi_child BEFORE INSERT ON Child FOR EACH ROW
BEGIN
  SET NEW.last_modified = now();
END;
|

CREATE TRIGGER bu_child BEFORE UPDATE ON Child FOR EACH ROW
BEGIN
  SET NEW.last_modified = now();
END;
|

CREATE TRIGGER bd_child BEFORE DELETE ON Child FOR EACH ROW
BEGIN
  INSERT INTO Track_Deletes_Child (id, time_deleted) VALUES (OLD.child_id, now() );
END;
|

CREATE TRIGGER bi_inventory BEFORE INSERT ON Inventory FOR EACH ROW
BEGIN
  SET NEW.last_modified = now();
END;
|

CREATE TRIGGER bu_inventory BEFORE UPDATE ON Inventory FOR EACH ROW
BEGIN
  SET NEW.last_modified = now();
END;
|

CREATE TRIGGER bd_inventory BEFORE DELETE ON Inventory FOR EACH ROW
BEGIN
  INSERT INTO Track_Deletes_Inventory (id, time_deleted) VALUES (OLD.inventory_id, now() );
END;
|

DELIMITER ;

CALL ml_add_table_script (
	mysql_v1,
	Admin,
	download_cursor,

SELECT Admin.admin_id,
	Admin.data
FROM Admin
WHERE Admin.last_modified >= {ml s.last_table_download}


);

CALL ml_add_table_script (
	mysql_v1,
	Admin,
	download_delete_cursor,

SELECT Track_Deletes_Admin.id
FROM Track_Deletes_Admin
WHERE Track_Deletes_Admin.time_deleted >= {ml s.last_table_download}


);

CALL ml_add_table_script (
	mysql_v1,
	Admin,
	upload_insert,

/* Insert the row into the consolidated database. */
INSERT INTO Admin ( admin_id, data )
VALUES ( {ml r.admin_id}, {ml r.data} )


);

CALL ml_add_table_script (
	mysql_v1,
	Admin,
	upload_delete,

/* Delete the row from the consolidated database. */
DELETE FROM Admin
WHERE admin_id = {ml r.admin_id}


);

CALL ml_add_table_script (
	mysql_v1,
	Admin,
	upload_update,

/* Update the row in the consolidated database. */
UPDATE Admin
SET data = {ml r.data}
WHERE admin_id = {ml r.admin_id}


);

CALL ml_add_table_script (
	mysql_v1,
	Admin,
	resolve_conflict,

/* Ignore the uploaded row, so that the consolidated values will win. */

BEGIN END;


);

CALL ml_add_table_script (
	mysql_v1,
	Child,
	download_cursor,

SELECT Child.child_id,
	Child.parent_id,
	Child.data
FROM Child
WHERE Child.last_modified >= {ml s.last_table_download}


);

CALL ml_add_table_script (
	mysql_v1,
	Child,
	download_delete_cursor,

SELECT Track_Deletes_Child.id
FROM Track_Deletes_Child
WHERE Track_Deletes_Child.time_deleted >= {ml s.last_table_download}


);

CALL ml_add_table_script (
	mysql_v1,
	Child,
	upload_insert,

/* Insert the row into the consolidated database. */
INSERT INTO Child ( child_id, parent_id, data )
VALUES ( {ml r.child_id}, {ml r.parent_id}, {ml r.data} )


);

CALL ml_add_table_script (
	mysql_v1,
	Child,
	upload_delete,

/* Delete the row from the consolidated database. */
DELETE FROM Child
WHERE child_id = {ml r.child_id}


);

CALL ml_add_table_script (
	mysql_v1,
	Child,
	upload_update,

/* Update the row in the consolidated database. */
UPDATE Child
SET parent_id = {ml r.parent_id},
	data = {ml r.data}
WHERE child_id = {ml r.child_id}


);

CALL ml_add_table_script (
	mysql_v1,
	Child,
	resolve_conflict,

/* Ignore the uploaded row, so that the consolidated values will win. */

BEGIN END;


);

CALL ml_add_table_script (
	mysql_v1,
	Inventory,
	download_cursor,

SELECT Inventory.inventory_id,
	Inventory.data
FROM Inventory
WHERE Inventory.last_modified >= {ml s.last_table_download}


);

CALL ml_add_table_script (
	mysql_v1,
	Inventory,
	download_delete_cursor,

SELECT Track_Deletes_Inventory.id
FROM Track_Deletes_Inventory
WHERE Track_Deletes_Inventory.time_deleted >= {ml s.last_table_download}


);

CALL ml_add_table_script (
	mysql_v1,
	Inventory,
	upload_insert,


/* Insert the row into the consolidated database. */
INSERT INTO Inventory ( inventory_id, data )
VALUES ( {ml r.inventory_id}, {ml r.data} )


);

CALL ml_add_table_script (
	mysql_v1,
	Inventory,
	upload_delete,

/* Delete the row from the consolidated database. */
DELETE FROM Inventory
WHERE inventory_id = {ml r.inventory_id}


);

CALL ml_add_table_script (
	mysql_v1,
	Inventory,
	upload_update,

/* Update the row in the consolidated database. */
UPDATE Inventory
SET data = {ml r.data}
WHERE inventory_id = {ml r.inventory_id}


);

CALL ml_add_table_script (
	mysql_v1,
	Inventory,
	resolve_conflict,

/* Ignore the uploaded row, so that the consolidated values will win. */

BEGIN END;


);

CALL ml_add_table_script (
	mysql_v1,
	Parent,
	download_cursor,

SELECT Parent.parent_id,
	Parent.user_id,
	Parent.data
FROM Parent
WHERE Parent.last_modified >= {ml s.last_table_download}


);

CALL ml_add_table_script (
	mysql_v1,
	Parent,
	download_delete_cursor,

SELECT Track_Deletes_Parent.id
FROM Track_Deletes_Parent
WHERE Track_Deletes_Parent.time_deleted >= {ml s.last_table_download}


);

CALL ml_add_table_script (
	mysql_v1,
	Parent,
	upload_insert,

/* Insert the row into the consolidated database. */
INSERT INTO Parent ( parent_id, user_id, data )
VALUES ( {ml r.parent_id}, {ml r.user_id}, {ml r.data} )


);

CALL ml_add_table_script (
	mysql_v1,
	Parent,
	upload_delete,

/* Delete the row from the consolidated database. */
DELETE FROM Parent
WHERE parent_id = {ml r.parent_id}


);

CALL ml_add_table_script (
	mysql_v1,
	Parent,
	upload_update,

/* Update the row in the consolidated database. */
UPDATE Parent
SET user_id = {ml r.user_id},
	data = {ml r.data}
WHERE parent_id = {ml r.parent_id}


);

CALL ml_add_table_script (
	mysql_v1,
	Parent,
	resolve_conflict,

/* Ignore the uploaded row, so that the consolidated values will win. */

BEGIN END;


);

CALL ml_add_column (
	mysql_v1,
	Admin,
	null,
	null
);
CALL ml_add_column (
	mysql_v1,
	Admin,
	admin_id,
	bigint
);
CALL ml_add_column (
	mysql_v1,
	Admin,
	data,
	varchar
);
CALL ml_add_column (
	mysql_v1,
	Child,
	null,
	null
);
CALL ml_add_column (
	mysql_v1,
	Child,
	child_id,
	bigint
);
CALL ml_add_column (
	mysql_v1,
	Child,
	parent_id,
	bigint
);
CALL ml_add_column (
	mysql_v1,
	Child,
	data,
	varchar
);
CALL ml_add_column (
	mysql_v1,
	Inventory,
	null,
	null
);
CALL ml_add_column (
	mysql_v1,
	Inventory,
	inventory_id,
	bigint
);
CALL ml_add_column (
	mysql_v1,
	Inventory,
	data,
	integer
);
CALL ml_add_column (
	mysql_v1,
	Parent,
	null,
	null
);
CALL ml_add_column (
	mysql_v1,
	Parent,
	parent_id,
	bigint
);
CALL ml_add_column (
	mysql_v1,
	Parent,
	user_id,
	varchar
);
CALL ml_add_column (
	mysql_v1,
	Parent,
	data,
	varchar
);