-- MySQL 5.0 Consolidated database with SQL Anywhere 11 remote using TCPIP Synchronization
-- SQL Anywhere Studio MobiLink Synchronization 11
-- Written by Joshua Savill
-- Product Manager - Sybase iAnywhere
-- September 9, 2008

/*------------------------------------------------------------------------------
*                           Set some Database Options.
*-----------------------------------------------------------------------------*/

set option public.Global_database_id = 123456789;
set option public.delete_old_logs = 'ON';

COMMIT;

/*------------------------------------------------------------------------------
*                           Create table 'DBA.Admin'.
*-----------------------------------------------------------------------------*/

IF EXISTS (SELECT * FROM SYS.SYSTABLE WHERE table_name = 'Admin') THEN
	DROP TABLE "DBA"."Admin";
END IF;

CREATE TABLE "DBA"."Admin"     (
	"admin_id" bigint default global autoincrement primary key,
	"data" varchar(30) null
);

COMMIT;
/*------------------------------------------------------------------------------
*                           Create table 'DBA.Child'.
*-----------------------------------------------------------------------------*/

IF EXISTS (SELECT * FROM SYS.SYSTABLE WHERE table_name = 'Child') THEN
	DROP TABLE "DBA"."Child";
END IF;

CREATE TABLE "DBA"."Child"     (
	"child_id" bigint default global autoincrement primary key,
	"parent_id" bigint null,
	"data" varchar(30) null
);

COMMIT;
/*------------------------------------------------------------------------------
*                         Create table 'DBA.Inventory'.
*-----------------------------------------------------------------------------*/

IF EXISTS (SELECT * FROM SYS.SYSTABLE WHERE table_name = 'Inventory') THEN
	DROP TABLE "DBA"."Inventory";
END IF;

CREATE TABLE "DBA"."Inventory"     (
	"inventory_id" bigint default global autoincrement primary key,
	"data" integer null
);

COMMIT;
/*------------------------------------------------------------------------------
*                          Create table 'DBA.Parent'.
*-----------------------------------------------------------------------------*/

IF EXISTS (SELECT * FROM SYS.SYSTABLE WHERE table_name = 'Parent') THEN
	DROP TABLE "DBA"."Parent";
END IF;

CREATE TABLE "DBA"."Parent"     (
	"parent_id" bigint default global autoincrement primary key,
	"user_id" varchar(128) null,
	"data" varchar(30) null
);

COMMIT;
/*------------------------------------------------------------------------------
*                          Procedures to add test data.
*-----------------------------------------------------------------------------*/

create procedure DBA.rep_data(in iter integer default 1,in do_commit integer default 0)
begin
  declare loop_var integer;
  
  set loop_var=0;
  while loop_var < iter loop
    insert into Admin(data) values(cast(RAND(*)*20+1 as char(10)));
    insert into Parent(user_id,data) values('rem100',cast(RAND(*)*20+1 as char(10)));
    insert into Child(parent_id,data) values(@@identity,cast(RAND(*)*20+1 as char(10)));
    set loop_var=loop_var+1;
    if do_commit = 1 then
      commit;
    end if
  end loop;
end;

create procedure DBA.rep_data_inventory(in iter integer default 1,in do_commit integer default 0)
begin
  declare loop_var integer;
  
  set loop_var=0;
  while loop_var < iter loop
    insert into Inventory(data) values(loop_var);
    set loop_var=loop_var+1;
    if do_commit = 1 then
      commit;
    end if
  end loop;
end;

/*------------------------------------------------------------------------------
*                           Create publication 'pub1'.
*-----------------------------------------------------------------------------*/
CREATE PUBLICATION "pub1" (
		TABLE "DBA"."Admin",
		TABLE "DBA"."Child",
		TABLE "DBA"."Inventory",
		TABLE "DBA"."Parent"
);

/*------------------------------------------------------------------------------
*                          Create the user 'rem100'.
*-----------------------------------------------------------------------------*/
CREATE SYNCHRONIZATION USER "rem100";

/*------------------------------------------------------------------------------
*                  Create subscription to 'pub1' for 'rem100'.
*-----------------------------------------------------------------------------*/
CREATE SYNCHRONIZATION SUBSCRIPTION TO "pub1" FOR "rem100"
		OPTIONS ScriptVersion='mysql_v1';

COMMIT;